From: Lin Chen <linx.z.c...@intel.com>

We hit a panic while doing cpu hotplug test.
<0>[  627.982857] Kernel panic - not syncing: smp_callin: CPU1 started up but 
did not get a callout!
<0>[  627.982864]
<4>[  627.982876] Pid: 0, comm: kworker/0:1 Tainted: G ...
<4>[  627.982883] Call Trace:
<4>[  627.982903]  [<c18f2977>] panic+0x66/0x16c
<4>[  627.982918]  [<c12234cc>] ? default_get_apic_id+0x1c/0x40
<4>[  627.982931]  [<c18ef96d>] start_secondary+0xda/0x252

During BSP bootup AP, it is possible that BSP be preempted before
finishing STARTUP sequence of AP(set cpu_callout_mask) which maybe cause
AP busy wait for it. At present, AP will wait for 2 seconds then panic.

This patch let AP waits for 60 seconds at maximum.

Signed-off-by: Yanmin Zhang <yanmin_zh...@linux.intel.com>
Signed-off-by: Chen LinX <linx.z.c...@intel.com>
---
 arch/x86/kernel/smpboot.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/arch/x86/kernel/smpboot.c b/arch/x86/kernel/smpboot.c
index 7c5a8c3..447aa3b 100644
--- a/arch/x86/kernel/smpboot.c
+++ b/arch/x86/kernel/smpboot.c
@@ -162,9 +162,9 @@ static void __cpuinit smp_callin(void)
         */

        /*
         * Waiting 2s total for startup (udelay is not yet working)
         */
-       timeout = jiffies + 2*HZ;
+       timeout = jiffies + 60*HZ;
        while (time_before(jiffies, timeout)) {
                /*
                 * Has the boot CPU finished it's STARTUP sequence?
@@ -162,9 +162,9 @@ static void __cpuinit smp_callin(void)

        /*
-        * Waiting 2s total for startup (udelay is not yet working)
+        * Waiting 60s total for startup (udelay is not yet working)
         */
--
1.7.1
--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Reply via email to